@@ -133,12 +133,11 @@ macro_rules! plots {
 /// let mut k=String::new();
 /// plotter.render(&mut k);
 /// ```
-
 ///
 #[macro_export]
 macro_rules! simple_fmt {
     ($data:expr,$title:expr,$xname:expr,$yname:expr) => {{
-        let canvas = poloto::render::canvas_builder().build();
+        let canvas = $crate::render::canvas_builder().build();
         let data = canvas.build_moved($data);
         let (bx, by) = data.bounds();
         let xt = $crate::ticks::from_default(bx);
